summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMark McLoughlin <markmc@redhat.com>2011-10-25 14:26:13 +0100
committerMark McLoughlin <markmc@redhat.com>2011-10-25 14:39:12 +0100
commitc00cfc642ae60d9139b4f173670ea77bdc8e5805 (patch)
treefb39587c6f7abee5db4b1d28ce9a3463e183f147
parentf398289a30a6331830d7284e4aeb5402c0f5c779 (diff)
venv: update distribute as well as pip
When you create a virtualenv, pip and setuptools/distribute is installed. When we later run install_venv.py to update the venv, we should be sure to grab the latest versions of pip and distribute otherwise issues like this one are masked: http://code.google.com/p/sqlalchemy-migrate/issues/detail?id=131 Change-Id: Id206be478ea6c5216dcee6f2f58dc91858c843f5
-rw-r--r--tools/install_venv.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/tools/install_venv.py b/tools/install_venv.py
index cfd4c6bd4..2ecd446e6 100644
--- a/tools/install_venv.py
+++ b/tools/install_venv.py
@@ -150,8 +150,9 @@ def pip_install(*args):
def install_dependencies(venv=VENV):
print 'Installing dependencies with pip (this can take a while)...'
# First things first, make sure our venv has the latest pip.
pip_install('pip')
+ pip_install('distribute')
# Install greenlet by hand - just listing it in the requires file does not
# get it in stalled in the right order
@@ -150,8 +150,9 @@ def pip_install(*args):
def install_dependencies(venv=VENV):
print 'Installing dependencies with pip (this can take a while)...'
- # First things first, make sure our venv has the latest pip.
+ # First things first, make sure our venv has the latest pip and distribute.
pip_install('pip')